@@ -96,7 +96,7 @@ void Updater::updateSources(bool useNetwork)
   //  _sources.push_back("http://localhost:2222/update220.gmic");
   //  _sourceIsStdLib["http://localhost:2222/update220.gmic"] = true;
 
-  SHOW(_sources);
+  // SHOW(_sources);
 }
 
 void Updater::startUpdate(int ageLimit, int timeout, bool useNetwork)
