@@ -5,10 +5,6 @@
 ;;   Description : Show how to call G'MIC commands from a GIMP script.
 ;;                 ( http://gmic.eu )
 ;;
-;;   Note : This script uses the GTK version of the plug-in, if you want to use
-;;          the Qt version instead, just replace the string 'gtk' by 'qt' when
-;;          it appears in the source.
-;;
 ;;   Copyright   : David Tschumperle
 ;;                 ( http://tschumperle.users.greyc.fr/ )
 ;;
@@ -55,7 +51,7 @@
     (gimp-image-add-layer img copy-layer -1)
 
     ;; Render a 3D mapped cube from the active layer, using G'MIC.
-    (plug-in-gmic-gtk 1 img drawable 1 0
+    (plug-in-gmic-qt 1 img drawable 1 0
                   (string-append
                    "v - " ; To have a silent output. Remove it to display errors from the G'MIC interpreter on stderr.
                    "fx_imageobject3d 1,{w},{h},0.5,"
@@ -65,7 +61,7 @@
                    ))
 
     ;; Merge two layers together, using the G'MIC 'edges' mode (this layer mode does not exist by default in GIMP).
-    (plug-in-gmic-gtk 1 img drawable 2 0 "v - compose_edges 1")
+    (plug-in-gmic-qt 1 img drawable 2 0 "v - compose_edges 1")
 
     )
 
